/*
 *   Copyright (C) 2019 CERN.
 *   Copyright (C) 2019 Northwestern University.
 *
 * Invenio App RDM is free software; you can redistribute it and/or modify it
 * under the terms of the MIT License; see LICENSE file for more details.
 */

.footer-global {
  color: @footerTextDarkColor;
  font-weight: 300;
  margin-top: auto;
  font-size: @font-size-base;
  padding-top: 1rem;

  & > .ui.grid {
    margin: 0rem;  // Default was `-1rem -1rem`
  }

  a {
    text-decoration: none;
    color: @footerTextLightColor;

    &:hover, &:focus {
      color: @footerTextDarkColor;
    }
  }
}

.footer-top {
  background-color: @footerLightColor;
}

.margin-small {
  margin: 0em 0em 0.5em;
}

.footer-bottom {
  background-color: @footerDarkColor;
  box-shadow: 0 2px 5px rgba(0,0,0,.2) inset;
}

.invenio-rdm-footer {
  text-align: left;
  align-self: inherit;
  width: 62.5%;
  padding: 1em 0em 1em 0em;
}

.rdm-footer {
  text-align: left;
  align-self: inherit;
  width: 25%;
  padding: 1em 0em 1em 0em;
}

#lang-code {
  min-width: 14em;
}

@media only screen and (max-width: 1024px) {
  .invenio-rdm-footer {
    width: 90%;
  }
}

@media only screen and (max-width: 767px) {
  .invenio-rdm-footer {
    width: 100%;
  }
  .rdm-footer {
    width: 33%;
  }
}

@media only screen and (max-width: 480px) {
  .rdm-footer {
    width: 33%;
  }
  #lang-code {
    min-width: 10em;
  }
}
